netapp_ontap.models.lun_map_lun API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.lun_map_lun`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class LunMapLunSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LunMapLun object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the lun_map_lun.

  `name: str GET POST`

    The name of the LUN. Valid in POST. A LUN is located within a volume. Optionally, it can be located within a qtree in a volume.
    LUN names are paths of the form "/vol/\[/\]/\" where the qtree name is optional. LUN names are simple names that share a namespace with LUNs within the same SVM. The name must begin with a letter or "_" and contain only "_" and alphanumeric characters. In specific cases, an optional snapshot-name can be used of the form "\[@\]". The snapshot name must not begin or end with whitespace.

    Example: /vol/volume1/qtree1/lun1

  `node: LunMapLunNode GET`

    The LUN node.

  `smbc: LunMapLunSmbc GET`

    "Properties related to SM-BC replication."

  `uuid: str GET POST`

    The unique identifier of the LUN. Valid in POST.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412